Module alignment_errors

Module alignment_errors 

Alignment Errors

Structs

ALIGNMENT_ERRORS_SPEC
Alignment Errors
R
Register ALIGNMENT_ERRORS reader

Type Aliases

COUNT_ALIGNMENT_ERROR_R
Field COUNT_ALIGNMENT_ERROR reader - Alignment errors - a 10 bit register counting frames that are not an integral number of bytes long and have bad CRC when their length is truncated to an integral number of bytes and are between 64 and 1518 bytes in length (1536 if bit 8 set in network configuration register, 10,240 bytes if bit 3 is set in the network configuration register). This register is also incremented if a symbol error is detected and the frame is of valid length and does not have an integral number of bytes.