pub struct R(/* private fields */);Expand description
Register RX_LENGTH_ERRORS reader
Implementations
Sourceimpl R
impl R
Sourcepub fn count_length_err(&self) -> COUNT_LENGTH_ERR_R
pub fn count_length_err(&self) -> COUNT_LENGTH_ERR_R
Bits 0:9 - Length field frame errors - this 10-bit register counts the number of frames received that have a measured length shorter than that extracted from the length field (bytes 13 and 14). This condition is only counted if the value of the length field is less than 0x0600, the frame is not of excessive length and checking is enabled through bit 16 of the network configuration register.
Methods from Deref<Target = R<RX_LENGTH_ERRORS_SPEC>>